pub struct BaseSchema {
hash_after_crypt: bool,
startup_tjs_not_encrypted: bool,
obfuscated_index: bool,
}Available on crate features
kirikiri and kirikiri-arc only.Fields
hash_after_crypt: boolstartup_tjs_not_encrypted: boolobfuscated_index: boolTrait Implementations
Sourceimpl AsRef<BaseSchema> for CabbageCxCrypt
impl AsRef<BaseSchema> for CabbageCxCrypt
Sourcefn as_ref(&self) -> &BaseSchema
fn as_ref(&self) -> &BaseSchema
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl AsRef<BaseSchema> for ChainReactionCrypt
impl AsRef<BaseSchema> for ChainReactionCrypt
Sourcefn as_ref(&self) -> &BaseSchema
fn as_ref(&self) -> &BaseSchema
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl AsRef<BaseSchema> for CxEncryption
impl AsRef<BaseSchema> for CxEncryption
Sourcefn as_ref(&self) -> &BaseSchema
fn as_ref(&self) -> &BaseSchema
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl AsRef<BaseSchema> for HxCryptLite
impl AsRef<BaseSchema> for HxCryptLite
Sourcefn as_ref(&self) -> &BaseSchema
fn as_ref(&self) -> &BaseSchema
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl AsRef<BaseSchema> for MadoCrypt
impl AsRef<BaseSchema> for MadoCrypt
Sourcefn as_ref(&self) -> &BaseSchema
fn as_ref(&self) -> &BaseSchema
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl AsRef<BaseSchema> for NanaCxCrypt
impl AsRef<BaseSchema> for NanaCxCrypt
Sourcefn as_ref(&self) -> &BaseSchema
fn as_ref(&self) -> &BaseSchema
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl AsRef<BaseSchema> for RiddleCxCrypt
impl AsRef<BaseSchema> for RiddleCxCrypt
Sourcefn as_ref(&self) -> &BaseSchema
fn as_ref(&self) -> &BaseSchema
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl AsRef<BaseSchema> for SenrenCxCrypt
impl AsRef<BaseSchema> for SenrenCxCrypt
Sourcefn as_ref(&self) -> &BaseSchema
fn as_ref(&self) -> &BaseSchema
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl AsRef<BaseSchema> for SisMikoCrypt
impl AsRef<BaseSchema> for SisMikoCrypt
Sourcefn as_ref(&self) -> &BaseSchema
fn as_ref(&self) -> &BaseSchema
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl AsRef<BaseSchema> for XanaduCrypt
impl AsRef<BaseSchema> for XanaduCrypt
Sourcefn as_ref(&self) -> &BaseSchema
fn as_ref(&self) -> &BaseSchema
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl Clone for BaseSchema
impl Clone for BaseSchema
Sourcefn clone(&self) -> BaseSchema
fn clone(&self) -> BaseSchema
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BaseSchema
impl Debug for BaseSchema
Sourceimpl<'de> Deserialize<'de> for BaseSchema
impl<'de> Deserialize<'de> for BaseSchema
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more